package com.devexperts.mdd.news.model;

import com.devexperts.mdd.news.event.NewsBody;
import com.devexperts.mdd.news.event.NewsFilter;
import com.devexperts.mdd.news.event.NewsKey;
import com.devexperts.mdd.news.event.NewsSummary;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;
import java.util.stream.Collectors;

/**
 * News list with the last available news key. Last news key is used to not receive duplicate news.
 * @see NewsService#findFullNewsForFilter(NewsFilter, NewsKey)
 */
public class FullNewsList implements Serializable
{
    private static final long serialVersionUID = 0L;

    private final List<NewsBody> news;
    private final NewsKey lastKey;

    public FullNewsList(List<NewsBody> news, NewsKey lastKey) {
        this.news = news;
        this.lastKey = lastKey;
    }

    /**
     * Returns list of news.
     * @return list of news (summary with a news body).
     */
    public List<NewsBody> getFullNews() {
        return news;
    }

    /**
     * Returns last news key for which the news list is valid.
     * @return last news key
     */
    public NewsKey getLastKey() {
        return lastKey;
    }

    public FullNewsList append(FullNewsList list) {
        List<NewsBody> result = new ArrayList<>();
        result.addAll(getFullNews());
        result.addAll(list.getFullNews());
        return new FullNewsList(result, list.getLastKey());
    }

    public NewsList toNewsList() {
        List<NewsSummary> summaries = news.stream().map(NewsBody::getSummary).collect(Collectors.toList());
        return new NewsList(summaries, lastKey);
    }
}
